/* tslint:disable */
/* eslint-disable */
export const memory: WebAssembly.Memory;
export function parse_map_package(a: number, b: number, c: number): void;
export function __wbg_mappackage_free(a: number): void;
export function __wbg_offset_free(a: number): void;
export function __wbg_get_offset_x(a: number): number;
export function __wbg_set_offset_x(a: number, b: number): void;
export function __wbg_get_offset_y(a: number): number;
export function __wbg_set_offset_y(a: number, b: number): void;
export function offset_new(): number;
export function mappackage_map_ext(a: number, b: number): void;
export function mappackage_src_size(a: number): number;
export function mappackage_set_dst_size(a: number, b: number): void;
export function mappackage_map_image_data(a: number, b: number): void;
export function mappackage_pic_to_position(a: number, b: number): number;
export function mappackage_position_to_pic(a: number, b: number): number;
export function position_distance_to(a: number, b: number): number;
export function __wbg_set_size_width(a: number, b: number): void;
export function __wbg_set_size_height(a: number, b: number): void;
export function __wbg_set_position_latitude(a: number, b: number): void;
export function __wbg_set_position_longitude(a: number, b: number): void;
export function __wbg_size_free(a: number): void;
export function __wbg_position_free(a: number): void;
export function __wbg_get_size_width(a: number): number;
export function __wbg_get_size_height(a: number): number;
export function __wbg_get_position_latitude(a: number): number;
export function __wbg_get_position_longitude(a: number): number;
export function greet(): void;
export function size_new(): number;
export function position_new(): number;
export function __wbindgen_add_to_stack_pointer(a: number): number;
export function __wbindgen_malloc(a: number): number;
export function __wbindgen_free(a: number, b: number): void;
export function __wbindgen_realloc(a: number, b: number, c: number): number;
